# Provide an option to build the Maven plugin.  As far as I can tell, RPM versions
# of Maven plugins are only really useful as BuildRequires for other RPMs and it's
# unlikely that an RPM would need to run Liquibase during its build process.
%bcond_with maven_plugin

Name: liquibase
Summary: Database Refactoring Tool
Version: 3.4.1
Release: 1%{?dist}
License: ASL 2.0
Group: Applications/Databases

# Liquibase does not distribute source releases. To generate:
#   git clone https://github.com/liquibase/liquibase.git
#   cd liquibase/
#   git archive --format=tar.gz --prefix=liquibase-3.4.1/ liquibase-parent-3.4.1 > liquibase-3.4.1.tar.gz
Source0: %{name}-%{version}.tar.gz

BuildRequires: java-devel >= 0:1.6.0
BuildRequires: javapackages-tools
BuildRequires: maven-local
BuildRequires: servlet
BuildRequires: snakeyaml >= 0:1.13
BuildRequires: mvn(org.springframework:spring-context)
BuildRequires: mvn(org.springframework:spring-beans)
BuildRequires: mvn(org.springframework:spring-core)
BuildRequires: mvn(org.jboss.weld.se:weld-se)
BuildRequires: mvn(org.apache.commons:commons-cli)
BuildRequires: mvn(org.apache.velocity:velocity)
BuildRequires: mvn(org.eclipse.jetty:jetty-servlet)
BuildRequires: mvn(javax.enterprise:cdi-api)

Requires: java-headless >= 0:1.6.0
Requires: javapackages-tools
Requires: servlet
Requires: snakeyaml >= 0:1.13
Requires: mvn(org.springframework:spring-context)
Requires: mvn(org.springframework:spring-beans)
Requires: mvn(org.springframework:spring-core)
Requires: mvn(org.jboss.weld.se:weld-se)
Requires: mvn(org.apache.commons:commons-cli)
Requires: mvn(org.apache.velocity:velocity)
Requires: mvn(org.eclipse.jetty:jetty-servlet)
Requires: mvn(javax.enterprise:cdi-api)

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildArch: noarch
Url: http://liquibase.org/

%description
LiquiBase is an open source (Apache 2.0 License), database-independent library
for tracking, managing and applying database changes. It is built on a simple
premise: All database changes are stored in a human readable but tracked in
source control.

%package javadoc
Group: Documentation
Summary: API documentation for %{name}

%description javadoc
This package contains %{summary}.

%if %{with maven_plugin}
%package maven-plugin
Group: Development/Tools
Summary: Maven plugin for %{name}
BuildRequires: mvn(org.apache.maven:maven-project)
BuildRequires: mvn(org.apache.maven:maven-core)
Requires: %{name} = %{version}-%{release}
Requires: maven

%description maven-plugin
%{summary}.
%endif

%prep
%setup -q

%pom_disable_module liquibase-osgi
%pom_disable_module liquibase-integration-tests
%pom_disable_module liquibase-debian
%pom_disable_module liquibase-rpm

%if %{without maven_plugin}
%pom_disable_module liquibase-maven-plugin
%endif

%pom_remove_dep org.springframework:spring %{name}-core
%pom_add_dep org.springframework:spring-core %{name}-core
%pom_add_dep org.springframework:spring-beans %{name}-core
%pom_add_dep org.springframework:spring-context %{name}-core

# Disable filtering of bundled JS, fonts, etc. which cause
# maven-filtering to fail with IOException (see MSHARED-325 and
# BZ 1077375).
%pom_add_plugin :maven-resources-plugin %{name}-core "
    <configuration>
      <nonFilteredFileExtensions>
        <nonFilteredFileExtension>js</nonFilteredFileExtension>
        <nonFilteredFileExtension>eot</nonFilteredFileExtension>
        <nonFilteredFileExtension>svg</nonFilteredFileExtension>
        <nonFilteredFileExtension>ttf</nonFilteredFileExtension>
        <nonFilteredFileExtension>woff</nonFilteredFileExtension>
        <nonFilteredFileExtension>xsd</nonFilteredFileExtension>
        <nonFilteredFileExtension>vm</nonFilteredFileExtension>
        <nonFilteredFileExtension>sh</nonFilteredFileExtension>
      </nonFilteredFileExtensions>
    </configuration>"

# Symlink liquibase/liquibase-core.jar to liquibase.jar
%mvn_file :%{name}-core %{name}/%{name}-core %{name}

# Remove all test dependencies.  We aren't running tests with this build.
%pom_xpath_remove "//pom:dependency[pom:scope='test']" %{name}-core
%pom_remove_plugin org.codehaus.gmaven:gmaven-plugin %{name}-core

%if %{with maven_plugin}
# Build maven plugin
%mvn_package ":liquibase-maven-plugin" %{name}-maven-plugin
%pom_add_dep org.apache.maven:maven-core %{name}-maven-plugin
%endif

%build
%mvn_build -f

%install
%mvn_install
%jpackage_script liquibase.integration.commandline.Main "" "" %{name} %{name} true

%clean
rm -rf %{buildroot}

%files -f .mfiles
%defattr(-,root,root)
%doc changelog.txt LICENSE.txt
%dir %{_javadir}/%{name}
%{_bindir}/%{name}

%if %{with maven_plugin}
%files maven-plugin -f .mfiles-%{name}-maven-plugin
%endif

%files javadoc -f .mfiles-javadoc
%doc LICENSE.txt

%changelog
* Tue Sep 15 2015 Alex Wood <awood@redhat.com> 3.4.1-1
- Update to 3.4.1

* Tue Jul 07 2015 Alex Wood <awood@redhat.com> 3.4.0-1
- Update to 3.4.0

* Tue Nov 04 2014 Alex Wood <awood@redhat.com> 3.3.0-1
- Update to 3.3.0

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Tue May 27 2014 Alex Wood <awood@redhat.com> 3.1.1-1
- Update to 3.1.1
- Switch to Maven based build

* Fri Mar 28 2014 Michael Simacek <msimacek@redhat.com> - 3.1.0-2
- Use Requires: java-headless rebuild (#1067528)

* Mon Jan 13 2014 Alex Wood <awood@redhat.com> 3.1.0-1
- Update to 3.1.0

* Mon Oct 28 2013 Alex Wood <awood@redhat.com> - 3.0.7-4
- Update to 3.0.7.
- Use jpackage-utils to generate launch script.
- Split javadoc into separate package.

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Wed Apr 17 2013 Alex Wood <awood@redhat.com> 2.0.5-2
- Build now requires servlet3 instead of servlet25.

* Wed Apr 03 2013 Alex Wood <awood@redhat.com> 2.0.5-1
- Updating to liquibase 2.0.5.

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.3-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.0.3-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu May 03 2012 Devan Goodwin <dgoodwin@rm-rf.ca> 2.0.3-7
- 818510: Fix offline failures looking for dbchangelog XSD.
  (dgoodwin@redhat.com)

* Mon Apr 16 2012 Devan Goodwin <dgoodwin@rm-rf.ca> 2.0.3-6
- Generate and package javadocs.
- Cleanup rpmlint warnings.
- Switched to using javadir macro.
- Switched to using build-classpath in launcher.
* Tue Apr 03 2012 Devan Goodwin <dgoodwin@rm-rf.ca> 2.0.3-5
- Spec cleanup. (dgoodwin@redhat.com)

* Mon Apr 02 2012 Devan Goodwin <dgoodwin@rm-rf.ca> 2.0.3-4
- Fix missing javax.servlet during compile. (dgoodwin@redhat.com)

* Fri Mar 30 2012 Devan Goodwin <dgoodwin@rm-rf.ca> 2.0.3-3
- Include documentation, better tar.gz generation. (dgoodwin@redhat.com)
- Add custom launcher script. (dgoodwin@redhat.com)
- Add build.xml to compile. (dgoodwin@redhat.com)

* Thu Mar 29 2012 Devan Goodwin <dgoodwin@redhat.com> 2.0.3-2
- Initial packaging attempt.


